@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2003-2007 Imendio AB
- * Copyright (C) 2007 Collabora Ltd.
+ * Copyright (C) 2007-2008 Collabora Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -43,7 +43,6 @@
 #include <libempathy/empathy-contact.h>
 #include <libempathy/empathy-debug.h>
 #include <libempathy/empathy-message.h>
-#include <libempathy/empathy-conf.h>
 #include <libempathy/empathy-utils.h>
 
 #include "empathy-chat-window.h"
@@ -52,6 +51,7 @@
 #include "empathy-contact-dialogs.h"
 #include "empathy-log-window.h"
 #include "empathy-new-chatroom-dialog.h"
+#include "empathy-conf.h"
 #include "empathy-preferences.h"
 #include "empathy-private-chat.h"
 #include "empathy-group-chat.h"
@@ -476,22 +476,12 @@ empathy_chat_window_get_default (void)
 
 	for (l = chat_windows; l; l = l->next) {
 		EmpathyChatWindow *chat_window;
-		GtkWidget        *dialog;
-		GdkWindow        *window;
-		gboolean          visible;
+		GtkWidget         *dialog;
 
 		chat_window = l->data;
 
 		dialog = empathy_chat_window_get_dialog (chat_window);
-		window = dialog->window;
-
-		g_object_get (dialog,
-			      "visible", &visible,
-			      NULL);
-
-		visible = visible && !(gdk_window_get_state (window) & GDK_WINDOW_STATE_ICONIFIED);
-
-		if (visible) {
+		if (empathy_window_get_is_visible (GTK_WINDOW (GTK_WINDOW (dialog)))) {
 			/* Found a visible window on this desktop */
 			return chat_window;
 		}
@@ -791,21 +781,21 @@ chat_window_update_menu (EmpathyChatWindow *window)
 						   chat_window_show_contacts_toggled_cb,
 						   window);
 	} else {
-		EmpathyPrivateChat  *chat;
-		EmpathyContact      *contact;
-		EmpathyPresence     *presence;
+		EmpathyPrivateChat *chat;
+		EmpathyContact     *contact;
+		McPresence          presence;
 
 		chat = EMPATHY_PRIVATE_CHAT (priv->current_chat);
 
 		/* Show / Hide widgets */
 		gtk_widget_hide (priv->menu_room);
 
-		/* presence==NULL means this contact refuses to send us his
+		/* Unset presence means this contact refuses to send us his
 		 * presence. By adding the contact we ask the contact to accept
 		 * to send his presence. */
 		contact = empathy_private_chat_get_contact (chat);
 		presence = empathy_contact_get_presence (contact);
-		if (!presence) {
+		if (presence == MC_PRESENCE_UNSET) {
 			gtk_widget_show (priv->menu_conv_add_contact);
 		} else {
 			gtk_widget_hide (priv->menu_conv_add_contact);
@@ -883,7 +873,7 @@ chat_window_call_activate_cb (GtkWidget         *menuitem,
 		chat = EMPATHY_PRIVATE_CHAT (priv->current_chat);
 		contact = empathy_private_chat_get_contact (chat);
 
-		empathy_call_contact (contact);
+		empathy_call_with_contact (contact);
 	}
 }
 
@@ -1636,16 +1626,7 @@ chat_window_drag_data_received (GtkWidget        *widget,
 		chat = empathy_chat_window_find_chat (account, id);
 
 		if (!chat) {
-			MissionControl *mc;
-
-			mc = empathy_mission_control_new ();
-			mission_control_request_channel (mc,
-							 empathy_contact_get_account (contact),
-							 TP_IFACE_CHANNEL_TYPE_TEXT,
-							 empathy_contact_get_handle (contact),
-							 TP_HANDLE_TYPE_CONTACT,
-							 NULL, NULL);
-			g_object_unref (mc);
+			empathy_chat_with_contact_id (account, id);
 			return;
 		}
 
